Summary: A subset of LAPACK routines redesigned for heterogeneous computing
Name: compat-scalapack
Version: 1.7.5
Release: 1%{?dist}
# This is freely distributable without any restrictions.
License: Public Domain
Group: Development/Libraries
URL: http://www.netlib.org/lapack-dev/
Source0: http://www.netlib.org/scalapack/scalapack-%{version}.tgz
BuildRequires: lapack-devel, blas-devel
BuildRequires: gcc-gfortran, glibc-devel
BuildRoot: %{_tmppath}/scalapack-%{version}-%{release}-root-%(%{__id_u} -n)
Patch0: scalapack-1.7-fedora.patch

%bcond_with mpich

%ifarch s390 s390x %{arm}
  # No OpenMPI support on these arches
  %bcond_with openmpi
%else
  %bcond_without openmpi
%endif

%if %{with mpich}
BuildRequires: compat-blacs-mpich-devel, mpich-devel
%endif
%if %{with openmpi}
BuildRequires: compat-blacs-openmpi-devel, openmpi-devel
%endif

%description
The ScaLAPACK (or Scalable LAPACK) library includes a subset 
of LAPACK routines redesigned for distributed memory MIMD 
parallel computers. It is currently written in a 
Single-Program-Multiple-Data style using explicit message 
passing for inter-processor communication. It assumes 
matrices are laid out in a two-dimensional block cyclic 
decomposition.

ScaLAPACK is designed for heterogeneous computing and is 
portable on any computer that supports MPI or PVM.

Like LAPACK, the ScaLAPACK routines are based on 
block-partitioned algorithms in order to minimize the frequency 
of data movement between different levels of the memory hierarchy. 
(For such machines, the memory hierarchy includes the off-processor 
memory of other processors, in addition to the hierarchy of registers, 
cache, and local memory on each processor.) The fundamental building 
blocks of the ScaLAPACK library are distributed memory versions (PBLAS) 
of the Level 1, 2 and 3 BLAS, and a set of Basic Linear Algebra 
Communication Subprograms (BLACS) for communication tasks that arise 
frequently in parallel linear algebra computations. In the ScaLAPACK 
routines, all inter-processor communication occurs within the PBLAS and the 
BLACS. One of the design goals of ScaLAPACK was to have the ScaLAPACK 
routines resemble their LAPACK equivalents as much as possible. 

%package common
Summary: Common files for scalapack
Group: Development/Libraries
Obsoletes: scalapack-common < 2.0

%description common
The ScaLAPACK (or Scalable LAPACK) library includes a subset
of LAPACK routines redesigned for distributed memory MIMD
parallel computers. It is currently written in a
Single-Program-Multiple-Data style using explicit message
passing for inter-processor communication. It assumes
matrices are laid out in a two-dimensional block cyclic
decomposition.

ScaLAPACK is designed for heterogeneous computing and is
portable on any computer that supports MPI or PVM.

Like LAPACK, the ScaLAPACK routines are based on
block-partitioned algorithms in order to minimize the frequency
of data movement between different levels of the memory hierarchy.
(For such machines, the memory hierarchy includes the off-processor
memory of other processors, in addition to the hierarchy of registers,
cache, and local memory on each processor.) The fundamental building
blocks of the ScaLAPACK library are distributed memory versions (PBLAS)
of the Level 1, 2 and 3 BLAS, and a set of Basic Linear Algebra
Communication Subprograms (BLACS) for communication tasks that arise
frequently in parallel linear algebra computations. In the ScaLAPACK
routines, all inter-processor communication occurs within the PBLAS and the
BLACS. One of the design goals of ScaLAPACK was to have the ScaLAPACK
routines resemble their LAPACK equivalents as much as possible.

This package contains common files which are not specific
to any MPI implementation.

%if %{with mpich}
%package mpich
Summary: ScaLAPACK libraries compiled against mpich
Group: Development/Libraries
Requires: %{name}-common = %{version}-%{release}
# For dir ownership
Requires: mpich
Obsoletes: scalapack-mpich2 < 2.0

%description mpich
The ScaLAPACK (or Scalable LAPACK) library includes a subset
of LAPACK routines redesigned for distributed memory MIMD
parallel computers. It is currently written in a
Single-Program-Multiple-Data style using explicit message
passing for inter-processor communication. It assumes
matrices are laid out in a two-dimensional block cyclic
decomposition.

ScaLAPACK is designed for heterogeneous computing and is
portable on any computer that supports MPI or PVM.

Like LAPACK, the ScaLAPACK routines are based on
block-partitioned algorithms in order to minimize the frequency
of data movement between different levels of the memory hierarchy.
(For such machines, the memory hierarchy includes the off-processor
memory of other processors, in addition to the hierarchy of registers,
cache, and local memory on each processor.) The fundamental building
blocks of the ScaLAPACK library are distributed memory versions (PBLAS)
of the Level 1, 2 and 3 BLAS, and a set of Basic Linear Algebra
Communication Subprograms (BLACS) for communication tasks that arise
frequently in parallel linear algebra computations. In the ScaLAPACK
routines, all inter-processor communication occurs within the PBLAS and the
BLACS. One of the design goals of ScaLAPACK was to have the ScaLAPACK
routines resemble their LAPACK equivalents as much as possible.

This package contains ScaLAPACK libraries compiled with mpich.
%endif

%if %{with openmpi}
%package openmpi
Summary: ScaLAPACK libraries compiled against openmpi
Group: Development/Libraries
Requires: %{name}-common = %{version}-%{release}
# For dir ownership
Requires: openmpi
Obsoletes: scalapack-openmpi < 2.0

%description openmpi
The ScaLAPACK (or Scalable LAPACK) library includes a subset
of LAPACK routines redesigned for distributed memory MIMD
parallel computers. It is currently written in a
Single-Program-Multiple-Data style using explicit message
passing for inter-processor communication. It assumes
matrices are laid out in a two-dimensional block cyclic
decomposition.

ScaLAPACK is designed for heterogeneous computing and is
portable on any computer that supports MPI or PVM.

Like LAPACK, the ScaLAPACK routines are based on
block-partitioned algorithms in order to minimize the frequency
of data movement between different levels of the memory hierarchy.
(For such machines, the memory hierarchy includes the off-processor
memory of other processors, in addition to the hierarchy of registers,
cache, and local memory on each processor.) The fundamental building
blocks of the ScaLAPACK library are distributed memory versions (PBLAS)
of the Level 1, 2 and 3 BLAS, and a set of Basic Linear Algebra
Communication Subprograms (BLACS) for communication tasks that arise
frequently in parallel linear algebra computations. In the ScaLAPACK
routines, all inter-processor communication occurs within the PBLAS and the
BLACS. One of the design goals of ScaLAPACK was to have the ScaLAPACK
routines resemble their LAPACK equivalents as much as possible.

This package contains ScaLAPACK libraries compiled with openmpi.
%endif

%prep
%setup -q -c -n scalapack-%{version}
%patch0 -p1
cd scalapack-%{version}/
sed -i 's!BLACSdir      =.*!BLACSdir      = %{_libdir}!' SLmake.inc
cd ..
for i in %{?with_mpich:mpich} %{?with_openmpi:openmpi}; do
  cp -a scalapack-%{version} scalapack-%{version}-$i
  sed -i "s|FOO|$i|g" scalapack-%{version}-$i/SLmake.inc
done

%build
%define dobuild() \
cd scalapack-%{version}-$MPI_COMPILER_NAME ; \
make lib ; \
cd ..

%if %{with mpich}
# Build mpich version
export MPI_COMPILER_NAME=mpich
%{_mpich_load}
RPM_OPT_FLAGS=`echo $CFLAGS`
%dobuild
%{_mpich_unload}
%endif

%if %{with openmpi}
# Build OpenMPI version
export MPI_COMPILER_NAME=openmpi
%{_openmpi_load}
RPM_OPT_FLAGS=`echo $CFLAGS`
%dobuild
%{_openmpi_unload}
%endif

%install
rm -fr ${RPM_BUILD_ROOT}
mkdir -p ${RPM_BUILD_ROOT}%{_libdir}
mkdir -p ${RPM_BUILD_ROOT}%{_bindir}

for i in %{?with_mpich:mpich} %{?with_openmpi:openmpi}; do
  mkdir -p %{buildroot}%{_libdir}/$i/lib/
  pushd scalapack-%{version}-$i
  for f in *.so*; do
    cp -f $f %{buildroot}%{_libdir}/$i/lib/$f
  done
  popd
  pushd %{buildroot}%{_libdir}/$i/lib/
  ln -fs libscalapack.so.1.0.0 libscalapack.so.1
  popd
done

# Copy docs
cd scalapack-%{version}
cp -f INSTALL/scalapack_install.ps ../
cp -f README ../

#cp -f TESTING/x* ${RPM_BUILD_ROOT}%{_bindir}

%clean
rm -fr ${RPM_BUILD_ROOT}

%files common
%defattr(-,root,root,-)
%doc scalapack_install.ps README
# %{_bindir}/x*

%if %{with mpich}
%files mpich
%defattr(-,root,root,-)
%{_libdir}/mpich/lib/libscalapack.so.*
%endif

%if %{with openmpi}
%files openmpi
%defattr(-,root,root,-)
%{_libdir}/openmpi/lib/libscalapack.so.*
%endif

%changelog
* Tue Nov 25 2014 Dave Love <d.love@liverpool.ac.uk> - 1.7.5-1
- Renamed as compataibility version for EPEL6

* Tue Mar  5 2013 Tom Callaway <spot@fedoraproject.org> - 1.7.5-17.1
- add EL conditionalization

* Thu Nov 15 2012 Tom Callaway <spot@fedoraproject.org> - 1.7.5-17
- rebuild for new mpich2

* Sat Jul 21 2012 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.7.5-16
- Rebuilt for https://fedoraproject.org/wiki/Fedora_18_Mass_Rebuild

* Sat Jan 14 2012 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.7.5-15
- Rebuilt for https://fedoraproject.org/wiki/Fedora_17_Mass_Rebuild

* Wed Aug 03 2011 Jussi Lehtola <jussilehtola@fedoraproject.org> - 1.7.5-14
- Bump spec.

* Wed Aug 03 2011 Jussi Lehtola <jussilehtola@fedoraproject.org> - 1.7.5-13
- Honor MPI guidelines wrt placement of libraries.
- Drop unnecessary module file.
- A few rpmlint fixes.

* Tue Mar 29 2011 Deji Akingunola <dakingun@gmail.com> - 1.7.5-12
- Rebuild for mpich2 soname bump

* Wed Feb 09 2011 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.7.5-12
- Rebuilt for https://fedoraproject.org/wiki/Fedora_15_Mass_Rebuild

* Tue Oct 19 2010 Deji Akingunola <dakingun@gmail.com> - 1.7.5-11
- Rebuild for both mpich2 and openmpi updates

* Wed Jul  7 2010 Tom "spot" Callaway <tcallawa@redhat.com> - 1.7.5-10
- Move all BuildRequires to the top of the spec file
- -static packages now Require matching -devel package, they're not very useful otherwise

* Wed Dec 15 2009 Deji Akingunola <dakingun@gmail.com> - 1.7.5-9
- Buildrequire mpich2-devel-static

* Wed Dec  9 2009 Tom "spot" Callaway <tcallawa@redhat.com> - 1.7.5-8
- drop lam support (Provides/Obsoletes by mpich2, which is a hack, but something's gotta do it)
- move static libs to static subpackages (resolves bz 545150)

* Thu Aug  6 2009 Tom "spot" Callaway <tcallawa@redhat.com> - 1.7.5-7
- rework package to handle all supported MPI environments in Fedora

* Sun Jul 26 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.7.5-6
- Rebuilt for https://fedoraproject.org/wiki/Fedora_12_Mass_Rebuild

* Wed Feb 25 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.7.5-5
- Rebuilt for https://fedoraproject.org/wiki/Fedora_11_Mass_Rebuild

* Tue Sep 23 2008 Tom "spot" Callaway <tcallawa@redhat.com> 1.7.5-4
- incorporate Deji Akingunola's changes (bz 462424)
- build against openmpi instead of lam

* Tue Jul  8 2008 Tom "spot" Callaway <tcallawa@redhat.com> 1.7.5-3
- fix compile against new lam paths

* Wed Feb 13 2008 Tom "spot" Callaway <tcallawa@redhat.com> 1.7.5-2
- rebuild for new gcc

* Mon Aug 27 2007 Tom "spot" Callaway <tcallawa@redhat.com> 1.7.5-1.1
- rebuild for BuildID

* Thu Jan 18 2007 Tom "spot" Callaway <tcallawa@redhat.com> 1.7.5-1
- bump to 1.7.5

* Fri Sep 15 2006 Tom "spot" Callaway <tcallawa@redhat.com> 1.7.4-4
- I said "BR" not "R". Stupid packager.

* Fri Sep 15 2006 Tom "spot" Callaway <tcallawa@redhat.com> 1.7.4-3
- fix BR: lam-devel

* Fri Sep 15 2006 Tom "spot" Callaway <tcallawa@redhat.com> 1.7.4-2
- fix 64bit patch

* Fri Sep 15 2006 Tom "spot" Callaway <tcallawa@redhat.com> 1.7.4-1
- bump to 1.7.4

* Wed Mar  8 2006 Tom "spot" Callaway <tcallawa@redhat.com> 1.7-13
- lam moved into _libdir/lam... need to fix patches

* Wed Mar  8 2006 Tom "spot" Callaway <tcallawa@redhat.com> 1.7-12
- set -fPIC as NOOPT

* Sun Feb 26 2006 Tom "spot" Callaway <tcallawa@redhat.com> 1.7-11
- fix 64 bit builds
- enable shared libraries
- split package into base and devel

* Tue Feb 14 2006 Tom "spot" Callaway <tcallawa@redhat.com> 1.7-10
- Incorporate Andrew Gormanly's fixes

* Mon Jan  9 2006 Tom "spot" Callaway <tcallawa@redhat.com> 1.7-9
- fix BR

* Mon Dec 19 2005 Tom "spot" Callaway <tcallawa@redhat.com> 1.7-8
- rebuild for gcc4.1

* Sun May 15 2005 Tom "spot" Callaway <tcallawa@redhat.com> 1.7-7
- 64 bit library fix

* Mon May  9 2005 Tom "spot" Callaway <tcallawa@redhat.com> 1.7-6
- remove hardcoded dist tags

* Sun May  8 2005 Tom "spot" Callaway <tcallawa@redhat.com> 1.7-4
- fix broken patch for fc-3 branch

* Sun Apr 24 2005 Tom "spot" Callaway <tcallawa@redhat.com> 1.7-3
- use dist tag
- fix fc3 BuildRequires

* Tue Apr 19 2005 Tom "spot" Callaway <tcallawa@redhat.com> 1.7-2
- fix buildroot
- add gcc-gfortran to BuildRequires (gcc-g77 for fc3)

* Mon Apr 18 2005 Tom "spot" Callaway <tcallawa@redhat.com> 1.7-1
- initial package creation
